# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_safconsole20250521 import models as main_models
from darabonba.model import DaraModel

class DescribeCustomerModuleMetaInfoResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        http_status_code: int = None,
        request_id: str = None,
        result_object: main_models.DescribeCustomerModuleMetaInfoResponseBodyResultObject = None,
        success: bool = None,
    ):
        # Status code. A return value of 200 indicates success.
        self.code = code
        # HTTP status code.
        self.http_status_code = http_status_code
        # Request ID
        self.request_id = request_id
        # Return result.
        self.result_object = result_object
        # Indicates whether the call was successful.
        # 
        # - **true**: Call succeeded.
        # - **false**: Call failed.
        self.success = success

    def validate(self):
        if self.result_object:
            self.result_object.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.result_object is not None:
            result['ResultObject'] = self.result_object.to_map()

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResultObject') is not None:
            temp_model = main_models.DescribeCustomerModuleMetaInfoResponseBodyResultObject()
            self.result_object = temp_model.from_map(m.get('ResultObject'))

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeCustomerModuleMetaInfoResponseBodyResultObject(DaraModel):
    def __init__(
        self,
        feature_list: List[main_models.DescribeCustomerModuleMetaInfoResponseBodyResultObjectFeatureList] = None,
        feature_template: str = None,
    ):
        # Feature list.
        self.feature_list = feature_list
        # Feature template.
        self.feature_template = feature_template

    def validate(self):
        if self.feature_list:
            for v1 in self.feature_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['FeatureList'] = []
        if self.feature_list is not None:
            for k1 in self.feature_list:
                result['FeatureList'].append(k1.to_map() if k1 else None)

        if self.feature_template is not None:
            result['FeatureTemplate'] = self.feature_template

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.feature_list = []
        if m.get('FeatureList') is not None:
            for k1 in m.get('FeatureList'):
                temp_model = main_models.DescribeCustomerModuleMetaInfoResponseBodyResultObjectFeatureList()
                self.feature_list.append(temp_model.from_map(k1))

        if m.get('FeatureTemplate') is not None:
            self.feature_template = m.get('FeatureTemplate')

        return self

class DescribeCustomerModuleMetaInfoResponseBodyResultObjectFeatureList(DaraModel):
    def __init__(
        self,
        default_value: str = None,
        feature_name: str = None,
        feature_type: str = None,
        name: str = None,
    ):
        # Default value of the feature.
        self.default_value = default_value
        # Feature mapping name.
        self.feature_name = feature_name
        # Feature type.
        self.feature_type = feature_type
        # Feature name.
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.default_value is not None:
            result['DefaultValue'] = self.default_value

        if self.feature_name is not None:
            result['FeatureName'] = self.feature_name

        if self.feature_type is not None:
            result['FeatureType'] = self.feature_type

        if self.name is not None:
            result['Name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DefaultValue') is not None:
            self.default_value = m.get('DefaultValue')

        if m.get('FeatureName') is not None:
            self.feature_name = m.get('FeatureName')

        if m.get('FeatureType') is not None:
            self.feature_type = m.get('FeatureType')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateCustomerModuleOutputInfoRequest(DaraModel):
    def __init__(
        self,
        customer_module_id: int = None,
        final_score_format: str = None,
        process_expression: str = None,
        test_file_url: str = None,
    ):
        # Customer model ID
        self.customer_module_id = customer_module_id
        # Number of decimal places to retain.
        self.final_score_format = final_score_format
        # Score processing logic.
        self.process_expression = process_expression
        # Test file URL.
        self.test_file_url = test_file_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.customer_module_id is not None:
            result['CustomerModuleId'] = self.customer_module_id

        if self.final_score_format is not None:
            result['FinalScoreFormat'] = self.final_score_format

        if self.process_expression is not None:
            result['ProcessExpression'] = self.process_expression

        if self.test_file_url is not None:
            result['TestFileUrl'] = self.test_file_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CustomerModuleId') is not None:
            self.customer_module_id = m.get('CustomerModuleId')

        if m.get('FinalScoreFormat') is not None:
            self.final_score_format = m.get('FinalScoreFormat')

        if m.get('ProcessExpression') is not None:
            self.process_expression = m.get('ProcessExpression')

        if m.get('TestFileUrl') is not None:
            self.test_file_url = m.get('TestFileUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_safconsole20250521 import models as main_models
from darabonba.model import DaraModel

class DescribeModelingProjectListResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        current_page: int = None,
        page_size: int = None,
        request_id: str = None,
        result_object: List[main_models.DescribeModelingProjectListResponseBodyResultObject] = None,
        success: bool = None,
        total_item: int = None,
        total_page: int = None,
    ):
        # Status code. A return value of 200 indicates success.
        self.code = code
        # Current page.
        self.current_page = current_page
        # Pagination parameter: number of items per page, with a default value of 10.
        self.page_size = page_size
        # Request ID.
        self.request_id = request_id
        # Returned result.
        self.result_object = result_object
        # Indicates whether the call was successful.
        # 
        # - **true**: Call succeeded.
        # - **false**: Call failed.
        self.success = success
        # Total number of records.
        self.total_item = total_item
        # Total number of pages.
        self.total_page = total_page

    def validate(self):
        if self.result_object:
            for v1 in self.result_object:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        result['ResultObject'] = []
        if self.result_object is not None:
            for k1 in self.result_object:
                result['ResultObject'].append(k1.to_map() if k1 else None)

        if self.success is not None:
            result['Success'] = self.success

        if self.total_item is not None:
            result['TotalItem'] = self.total_item

        if self.total_page is not None:
            result['TotalPage'] = self.total_page

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        self.result_object = []
        if m.get('ResultObject') is not None:
            for k1 in m.get('ResultObject'):
                temp_model = main_models.DescribeModelingProjectListResponseBodyResultObject()
                self.result_object.append(temp_model.from_map(k1))

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('TotalItem') is not None:
            self.total_item = m.get('TotalItem')

        if m.get('TotalPage') is not None:
            self.total_page = m.get('TotalPage')

        return self

class DescribeModelingProjectListResponseBodyResultObject(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        env_status: str = None,
        login_account: str = None,
        modeling_status: str = None,
        project_id: str = None,
        project_name: str = None,
        start_time: int = None,
    ):
        # End time of the secure modeling project.
        self.end_time = end_time
        # Secure environment status.
        self.env_status = env_status
        # Login account.
        self.login_account = login_account
        # Modeling project status.
        self.modeling_status = modeling_status
        # Project ID.
        self.project_id = project_id
        # Project name.
        self.project_name = project_name
        # Start time of the secure modeling project.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.env_status is not None:
            result['EnvStatus'] = self.env_status

        if self.login_account is not None:
            result['LoginAccount'] = self.login_account

        if self.modeling_status is not None:
            result['ModelingStatus'] = self.modeling_status

        if self.project_id is not None:
            result['ProjectId'] = self.project_id

        if self.project_name is not None:
            result['ProjectName'] = self.project_name

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('EnvStatus') is not None:
            self.env_status = m.get('EnvStatus')

        if m.get('LoginAccount') is not None:
            self.login_account = m.get('LoginAccount')

        if m.get('ModelingStatus') is not None:
            self.modeling_status = m.get('ModelingStatus')

        if m.get('ProjectId') is not None:
            self.project_id = m.get('ProjectId')

        if m.get('ProjectName') is not None:
            self.project_name = m.get('ProjectName')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribeCustomerModuleOutputInfoRequest(DaraModel):
    def __init__(
        self,
        auth_type: str = None,
        customer_module_id: int = None,
    ):
        # Authorization type.
        self.auth_type = auth_type
        # Customer model ID
        self.customer_module_id = customer_module_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auth_type is not None:
            result['AuthType'] = self.auth_type

        if self.customer_module_id is not None:
            result['CustomerModuleId'] = self.customer_module_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AuthType') is not None:
            self.auth_type = m.get('AuthType')

        if m.get('CustomerModuleId') is not None:
            self.customer_module_id = m.get('CustomerModuleId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_safconsole20250521 import models as main_models
from darabonba.model import DaraModel

class DescribeModelingProjectDetailResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        request_id: str = None,
        result_object: main_models.DescribeModelingProjectDetailResponseBodyResultObject = None,
        success: bool = None,
    ):
        # Status code. A return value of 200 indicates success.
        self.code = code
        # Request ID.
        self.request_id = request_id
        # Returned result.
        self.result_object = result_object
        # Whether the call was successful.
        # 
        # - **true**: Call succeeded.
        # - **false**: Call failed.
        self.success = success

    def validate(self):
        if self.result_object:
            self.result_object.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.result_object is not None:
            result['ResultObject'] = self.result_object.to_map()

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResultObject') is not None:
            temp_model = main_models.DescribeModelingProjectDetailResponseBodyResultObject()
            self.result_object = temp_model.from_map(m.get('ResultObject'))

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeModelingProjectDetailResponseBodyResultObject(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        env_status: str = None,
        login_account: str = None,
        machine_spec: str = None,
        manual_phase: str = None,
        modeling_status: str = None,
        poc_tasks: List[main_models.DescribeModelingProjectDetailResponseBodyResultObjectPocTasks] = None,
        project_id: str = None,
        project_name: str = None,
        remark: str = None,
        start_time: int = None,
        synced_files: List[main_models.DescribeModelingProjectDetailResponseBodyResultObjectSyncedFiles] = None,
    ):
        # End time of the security modeling project.
        self.end_time = end_time
        # Security environment status.
        self.env_status = env_status
        # Login account.
        self.login_account = login_account
        # Machine specification.
        self.machine_spec = machine_spec
        # Manual operation phase.
        self.manual_phase = manual_phase
        # Modeling project status.
        self.modeling_status = modeling_status
        # Associated POC tasks.
        self.poc_tasks = poc_tasks
        # Project ID
        self.project_id = project_id
        # Project name.
        self.project_name = project_name
        # Remark information.
        self.remark = remark
        # Start time of the security modeling project.
        self.start_time = start_time
        # Synchronized files.
        self.synced_files = synced_files

    def validate(self):
        if self.poc_tasks:
            for v1 in self.poc_tasks:
                 if v1:
                    v1.validate()
        if self.synced_files:
            for v1 in self.synced_files:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.env_status is not None:
            result['EnvStatus'] = self.env_status

        if self.login_account is not None:
            result['LoginAccount'] = self.login_account

        if self.machine_spec is not None:
            result['MachineSpec'] = self.machine_spec

        if self.manual_phase is not None:
            result['ManualPhase'] = self.manual_phase

        if self.modeling_status is not None:
            result['ModelingStatus'] = self.modeling_status

        result['PocTasks'] = []
        if self.poc_tasks is not None:
            for k1 in self.poc_tasks:
                result['PocTasks'].append(k1.to_map() if k1 else None)

        if self.project_id is not None:
            result['ProjectId'] = self.project_id

        if self.project_name is not None:
            result['ProjectName'] = self.project_name

        if self.remark is not None:
            result['Remark'] = self.remark

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        result['SyncedFiles'] = []
        if self.synced_files is not None:
            for k1 in self.synced_files:
                result['SyncedFiles'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('EnvStatus') is not None:
            self.env_status = m.get('EnvStatus')

        if m.get('LoginAccount') is not None:
            self.login_account = m.get('LoginAccount')

        if m.get('MachineSpec') is not None:
            self.machine_spec = m.get('MachineSpec')

        if m.get('ManualPhase') is not None:
            self.manual_phase = m.get('ManualPhase')

        if m.get('ModelingStatus') is not None:
            self.modeling_status = m.get('ModelingStatus')

        self.poc_tasks = []
        if m.get('PocTasks') is not None:
            for k1 in m.get('PocTasks'):
                temp_model = main_models.DescribeModelingProjectDetailResponseBodyResultObjectPocTasks()
                self.poc_tasks.append(temp_model.from_map(k1))

        if m.get('ProjectId') is not None:
            self.project_id = m.get('ProjectId')

        if m.get('ProjectName') is not None:
            self.project_name = m.get('ProjectName')

        if m.get('Remark') is not None:
            self.remark = m.get('Remark')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        self.synced_files = []
        if m.get('SyncedFiles') is not None:
            for k1 in m.get('SyncedFiles'):
                temp_model = main_models.DescribeModelingProjectDetailResponseBodyResultObjectSyncedFiles()
                self.synced_files.append(temp_model.from_map(k1))

        return self

class DescribeModelingProjectDetailResponseBodyResultObjectSyncedFiles(DaraModel):
    def __init__(
        self,
        deployable: bool = None,
        files: List[main_models.DescribeModelingProjectDetailResponseBodyResultObjectSyncedFilesFiles] = None,
        group_id: int = None,
        group_name: str = None,
        synced_time: str = None,
    ):
        # Whether deployment is supported.
        self.deployable = deployable
        # Files generated by modeling.
        self.files = files
        # Application group ID.
        self.group_id = group_id
        # File group name.
        self.group_name = group_name
        # Synchronization time.
        self.synced_time = synced_time

    def validate(self):
        if self.files:
            for v1 in self.files:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.deployable is not None:
            result['Deployable'] = self.deployable

        result['Files'] = []
        if self.files is not None:
            for k1 in self.files:
                result['Files'].append(k1.to_map() if k1 else None)

        if self.group_id is not None:
            result['GroupId'] = self.group_id

        if self.group_name is not None:
            result['GroupName'] = self.group_name

        if self.synced_time is not None:
            result['SyncedTime'] = self.synced_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Deployable') is not None:
            self.deployable = m.get('Deployable')

        self.files = []
        if m.get('Files') is not None:
            for k1 in m.get('Files'):
                temp_model = main_models.DescribeModelingProjectDetailResponseBodyResultObjectSyncedFilesFiles()
                self.files.append(temp_model.from_map(k1))

        if m.get('GroupId') is not None:
            self.group_id = m.get('GroupId')

        if m.get('GroupName') is not None:
            self.group_name = m.get('GroupName')

        if m.get('SyncedTime') is not None:
            self.synced_time = m.get('SyncedTime')

        return self

class DescribeModelingProjectDetailResponseBodyResultObjectSyncedFilesFiles(DaraModel):
    def __init__(
        self,
        downloadable: bool = None,
        file_id: int = None,
        file_name: str = None,
        visible: bool = None,
    ):
        # Whether it is downloadable.
        self.downloadable = downloadable
        # The ID of the file.
        self.file_id = file_id
        # The name of the file.
        self.file_name = file_name
        # Visibility:
        # 
        # **true**: Visible
        # 
        # **false**: Not visible
        self.visible = visible

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.downloadable is not None:
            result['Downloadable'] = self.downloadable

        if self.file_id is not None:
            result['FileId'] = self.file_id

        if self.file_name is not None:
            result['FileName'] = self.file_name

        if self.visible is not None:
            result['Visible'] = self.visible

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Downloadable') is not None:
            self.downloadable = m.get('Downloadable')

        if m.get('FileId') is not None:
            self.file_id = m.get('FileId')

        if m.get('FileName') is not None:
            self.file_name = m.get('FileName')

        if m.get('Visible') is not None:
            self.visible = m.get('Visible')

        return self

class DescribeModelingProjectDetailResponseBodyResultObjectPocTasks(DaraModel):
    def __init__(
        self,
        file_name: str = None,
        service_code: str = None,
        status: str = None,
        task_name: str = None,
    ):
        # Retrospective file name.
        self.file_name = file_name
        # Service code
        self.service_code = service_code
        # File synchronization status.
        self.status = status
        # Retrospective task name.
        self.task_name = task_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.file_name is not None:
            result['FileName'] = self.file_name

        if self.service_code is not None:
            result['ServiceCode'] = self.service_code

        if self.status is not None:
            result['Status'] = self.status

        if self.task_name is not None:
            result['TaskName'] = self.task_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FileName') is not None:
            self.file_name = m.get('FileName')

        if m.get('ServiceCode') is not None:
            self.service_code = m.get('ServiceCode')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TaskName') is not None:
            self.task_name = m.get('TaskName')

        return self

